@@ -1,4 +1,3 @@
-import logging
 from simple_rest_client.api import API
 from simple_rest_client.resource import AsyncResource
 
@@ -6,13 +5,12 @@ from simple_rest_client.resource import AsyncResource
 class Client:
 
     def __init__(self, api_name, resources, api_version=None, session=None):
-        self.api_version = api_version or '2.26'
+        self.api_version = api_version
         self.api_name = api_name
         self.resources = resources
         self.session = session
         if self.session is None:
-            logging.error("provided session object is None, probably auth error?")
-            raise AttributeError()
+            raise AttributeError("provided session object is None, probably auth error?")
 
     async def init_api(self):
         await self.get_credentials()
@@ -26,4 +24,4 @@ class Client:
 
     async def get_credentials(self):
         await self.session.authenticate()
-        self.api_url = await self.session.get_ednpoint_url(self.api_name)
+        self.api_url = self.session.get_endpoint_url(self.api_name)
